==> haskell-crypton-x509-1.7.6-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509
version:              1.7.6
visibility:           public
id:                   crypton-x509-1.7.6-6XiV39cWEnH9pt2bejdztP
key:                  crypton-x509-1.7.6-6XiV39cWEnH9pt2bejdztP
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  dcf00a9fa46f868f83f6bdc15e78260c
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509
hs-libraries:         HScrypton-x509-1.7.6-6XiV39cWEnH9pt2bejdztP
depends:
    asn1-encoding-0.9.6-EXgXAY8T8qtDb1kOL1bzIM
    asn1-parse-0.9.5-Ca5rg6vFRn63jpNP2S5ml
    asn1-types-0.3.4-EtjGfufAHHPEmxZ69jeDoj base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-0.34-AnSidFHC7ns4WvqjSEiG61
    hourglass-0.2.12-JFcQJOlDPoZ93vxYqbNuj
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    pem-0.2.4-9s9yxgUU9XO6oalgR7gdEj transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509/html/crypton-x509.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-1.7.6-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509
version:              1.7.6
visibility:           public
id:                   crypton-x509-1.7.6-21jHoZZMfcu6wn4sl6XDpf
key:                  crypton-x509-1.7.6-21jHoZZMfcu6wn4sl6XDpf
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  e99e1ed4363722aa359cf1c08840c619
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509
hs-libraries:         HScrypton-x509-1.7.6-21jHoZZMfcu6wn4sl6XDpf
depends:
    asn1-encoding-0.9.6-AgpvwtLmnm79kPwPKQQ69U
    asn1-parse-0.9.5-9P41MpG5pH357LmIJydvm4
    asn1-types-0.3.4-ENmPSjrdsJ8K6KEFKJTmqN base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-0.34-6XOMFbDfdYBJsq0blw7Pbh
    hourglass-0.2.12-JxQpnPSwkfMGPI84TCXJZ
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    pem-0.2.4-AS6duoRdgrq7yC69dOVCY8 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509/html/crypton-x509.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
